@@ -9,7 +9,26 @@ use crate::{lexer::cursor::Cursor, Error};
 pub use token::Token;
 pub use token_kind::TokenKind;
 /// Parses tokens into text.
-pub(crate) struct Lexer {
+/// ```rust
+/// use apollo_parser::Lexer;
+///
+/// let query = "
+/// {
+///     animal
+///     ...snackSelection
+///     ... on Pet {
+///       playmates {
+///         count
+///       }
+///     }
+/// }
+/// ";
+/// let lexer = Lexer::new(query);
+/// assert_eq!(lexer.errors().len(), 0);
+///
+/// let tokens = lexer.tokens();
+/// ```
+pub struct Lexer {
     tokens: Vec<Token>,
     errors: Vec<Error>,
 }
@@ -56,12 +75,12 @@ impl Lexer {
     }
 
     /// Get a reference to the lexer's tokens.
-    pub(crate) fn tokens(&self) -> &[Token] {
+    pub fn tokens(&self) -> &[Token] {
         self.tokens.as_slice()
     }
 
     /// Get a reference to the lexer's tokens.
-    pub(crate) fn errors(&self) -> Iter<'_, Error> {
+    pub fn errors(&self) -> Iter<'_, Error> {
         self.errors.iter()
     }
 }
