@@ -87,7 +87,7 @@ impl Parser {
         let mut tokens = Vec::new();
         let mut errors = Vec::new();
 
-        for s in lexer.tokens().to_owned() {
+        for s in lexer.tokens().iter().cloned() {
             tokens.push(s);
         }
 
@@ -134,7 +134,7 @@ impl Parser {
     }
 
     /// Consume ignored tokens and add them to the AST.
-    fn bump_ignored(&mut self) {
+    pub(crate) fn bump_ignored(&mut self) {
         while let Some(TokenKind::Comment | TokenKind::Whitespace | TokenKind::Comma) = self.peek()
         {
             if let Some(TokenKind::Comment) = self.peek() {
@@ -244,6 +244,15 @@ impl Parser {
         self.tokens.last()
     }
 
+    /// Peek Token `n` and return it.
+    pub(crate) fn peek_token_n(&self, n: usize) -> Option<&Token> {
+        self.tokens
+            .iter()
+            .rev()
+            .filter(|token| !matches!(token.kind(), TokenKind::Whitespace | TokenKind::Comment))
+            .nth(n - 1)
+    }
+
     /// Peek Token `n` and return its TokenKind.
     pub(crate) fn peek_n(&self, n: usize) -> Option<TokenKind> {
         self.tokens
